pub fn handled_as_special_function_call<'tcx>(
    fpb: &mut FuncPAGBuilder<'_, 'tcx, '_>,
    callee_def_id: &DefId,
    gen_args: &GenericArgsRef<'tcx>,
    args: &Vec<Rc<Path>>,
    destination: &Rc<Path>,
    location: Location
) -> bool
Handling calls to special functions.

Returns true if this callee function is handled as a special function. If the return result is false, we need to continue with the normal logic.