Enum rupta::graph::pag::PAGEdgeEnum

source ·
pub enum PAGEdgeEnum {
    AddrPAGEdge,
    DirectPAGEdge,
    LoadPAGEdge(ProjectionElems),
    StorePAGEdge(ProjectionElems),
    GepPAGEdge(ProjectionElems),
    CastPAGEdge,
    OffsetPAGEdge,
}

Variants



AddrPAGEdge

Statements that create a reference or a raw pointer to a place.



DirectPAGEdge

Statements that create a value by direct assignment, including Move and Copy statements.



LoadPAGEdge(ProjectionElems)

Statements that create a value by loading the value pointed by a pointer. e.g. _2 = (*_3), _2 = (*_3).0.1.



StorePAGEdge(ProjectionElems)

Statements that store a value to a pointer’s pointee. e.g. (*_1) = _2, (*_1).0.1 = _2.



GepPAGEdge(ProjectionElems)

Similar to GetElementPtr instruction in llvm ir, get an element’s address from a pointed-to object, e.g. _2 = &((*_3).0.1)



CastPAGEdge

Cast a pointer to another type



OffsetPAGEdge

Statements that offset a pointer.