Struct rupta::mir::context::Context

source ·
pub struct Context<E: ContextElement> { /* private fields */ }
A context is composed of a list of context elements, e.g. callsites.

Implementations

source

impl<E: ContextElement> Context<E>

source

pub fn new_empty() -> Rc<Self>

source

pub fn new(context_elems: Vec<E>) -> Rc<Self>

source

pub fn len(&self) -> usize

source

pub fn new_k_limited_context( old_ctx: &Rc<Context<E>>, elem: E, k: usize ) -> Rc<Self>

Composes a new context from a given context and a new context element. Discard the last old context element if the length of context exceeds the depth limit.

source

pub fn k_limited_context(ctx: &Rc<Context<E>>, k: usize) -> Rc<Self>

source

pub fn first_context_element(&self) -> Option<&E>

source

pub fn last_context_element(&self) -> Option<&E>