Struct rupta::mir::context::ContextCache
source · pub struct ContextCache<E: ContextElement> { /* private fields */ }Expand description
Maintaing the contexts used.
Implementations
sourceimpl<E: ContextElement> ContextCache<E>
impl<E: ContextElement> ContextCache<E>
pub fn new() -> ContextCache<E>
sourcepub fn get_context_id(&mut self, context: &Rc<Context<E>>) -> ContextId
pub fn get_context_id(&mut self, context: &Rc<Context<E>>) -> ContextId
Returns a non zero index that can be used to retrieve context via get_context.
sourcepub fn get_context(&self, id: ContextId) -> Option<Rc<Context<E>>>
pub fn get_context(&self, id: ContextId) -> Option<Rc<Context<E>>>
Returns the type that was stored at this index, or None if index is zero or greater than the length of the type list.
pub fn context_list(&self) -> &IndexVec<ContextId, Rc<Context<E>>>