Struct rupta::mir::function::FunctionReference
source · pub struct FunctionReference<'tcx> {
pub def_id: DefId,
pub generic_args: Vec<GenericArgE<'tcx>>,
pub promoted: Option<Promoted>,
}Expand description
Information that identifies a function instance.
Fields
def_id: DefIdThe crate specific key that is used to identify the function in the current crate.
generic_args: Vec<GenericArgE<'tcx>>The generic argument types with which the referenced function was instantiated, if generic.
promoted: Option<Promoted>Promoteds do not have their own DefId. The body references promoteds by the DefId and the mir::Promoted index.
Implementations
sourceimpl<'tcx> FunctionReference<'tcx>
impl<'tcx> FunctionReference<'tcx>
pub fn new_function_reference( def_id: DefId, generic_args: Vec<GenericArgE<'tcx>> ) -> Rc<FunctionReference<'tcx>>
pub fn new_promoted_reference( def_id: DefId, generic_args: Vec<GenericArgE<'tcx>>, promoted: Promoted ) -> Rc<FunctionReference<'tcx>>