pub struct KnownNamesCache { /* private fields */ }
An analysis lifetime cache that contains a map from def ids to known names.

Implementations

source

impl KnownNamesCache

source

pub fn create_cache_from_language_items() -> KnownNamesCache

Create an empty known names cache. This cache is re-used by every successive MIR visitor instance.

source

pub fn get(&mut self, tcx: TyCtxt<'_>, def_id: DefId) -> KnownNames

Get the well known name for the given def id and cache the association. I.e. the first call for an unknown def id will be somewhat costly but subsequent calls will be cheap. If the def_id does not have an actual well known name, this returns KnownNames::None.