Enum rupta::mir::path::PathEnum

source ·
pub enum PathEnum {
Show 14 variants LocalVariable { func_id: FuncId, ordinal: usize, }, Parameter { func_id: FuncId, ordinal: usize, }, ReturnValue { func_id: FuncId, }, Auxiliary { func_id: FuncId, ordinal: usize, }, HeapObj { func_id: FuncId, location: Location, }, Constant, StaticVariable { def_id: DefId, }, PromotedConstant { def_id: DefId, ordinal: usize, }, QualifiedPath { base: Rc<Path>, projection: ProjectionElems, }, OffsetPath { base: Rc<Path>, offset: usize, }, Function(FuncId), PromotedStrRefArray, PromotedArgumentV1Array, Type(usize),
}
Different kinds of Path used in our analysis.

Variants



LocalVariable

Fields

func_id: FuncId
ordinal: usize

Locals [arg_count+1..] are the local variables and compiler temporaries.



Parameter

Fields

func_id: FuncId
ordinal: usize

Locals [1..=arg_count] are the parameters



ReturnValue

Fields

func_id: FuncId

Local 0 is the return value temporary



Auxiliary

Fields

func_id: FuncId
ordinal: usize

Auxiliary local variable created when running pointer analysis



HeapObj

Fields

func_id: FuncId
location: Location

A dynamically allocated memory object.



Constant

This path points to data that is not used, but exists only to satisfy a static checker that a generic parameter is actually used.



StaticVariable

Fields

def_id: DefId


PromotedConstant

Fields

def_id: DefId
ordinal: usize

The ordinal is an index into a method level table of MIR bodies.



QualifiedPath

Fields

base: Rc<Path>
projection: ProjectionElems

The base denotes some struct, collection or heap_obj. projection: a non-empty list of projections



OffsetPath

Fields

base: Rc<Path>
offset: usize


Function(FuncId)

A function instance which can be pointed to by a function pointer.



PromotedStrRefArray



PromotedArgumentV1Array



Type(usize)

A type instance uniquely identified by the type’s index in type cache