Struct rupta::mir::path::Path

source ·
pub struct Path {
    pub value: PathEnum,
}
The customized representation for a local variable, heap objects, …

Resembles the Place type in rustc.

Fields

value: PathEnum

Implementations

source

impl Path

source

pub fn new_local(func_id: FuncId, ordinal: usize) -> Rc<Path>

Creates a path to the local variable corresponding to the ordinal.

source

pub fn new_parameter(func_id: FuncId, ordinal: usize) -> Rc<Path>

Creates a path to the parameter corresponding to the ordinal.

source

pub fn new_return_value(func_id: FuncId) -> Rc<Path>

Creates a path to the return value.

source

pub fn new_local_parameter_or_result( func_id: FuncId, ordinal: usize, argument_count: usize ) -> Rc<Path>

Creates a path to the local variable, parameter or result local, corresponding to the ordinal.

source

pub fn new_aux(func_id: FuncId, ordinal: usize) -> Rc<Path>

Creates a new auxiliary path.

source

pub fn new_heap_obj(func_id: FuncId, location: Location) -> Rc<Path>

Creates a path to the heap object.

source

pub fn new_constant() -> Rc<Path>

Creates a path to a constant.

source

pub fn new_static_variable(def_id: DefId) -> Rc<Path>

Creates a path to a static variable.

source

pub fn new_promoted(def_id: DefId, ordinal: usize) -> Rc<Path>

Creates a path to a promoted constant.

source

pub fn new_argumentv1_arr() -> Rc<Path>

Creates a path to a argumentv1 array.

source

pub fn new_str_ref_arr() -> Rc<Path>

Creates a path to a &str array.

source

pub fn new_qualified(base: Rc<Path>, projection: ProjectionElems) -> Rc<Path>

Creates a path that qualifies the given root path with the given projection.

source

pub fn new_offset(base: Rc<Path>, offset: usize) -> Rc<Path>

Creates a path that qualifies the given root path with the given offset.

source

pub fn new_index(collection_path: Rc<Path>) -> Rc<Path>

Creates a path that selects the element at a given index value of the array at the given path.

source

pub fn new_field(base: Rc<Path>, field_index: usize) -> Rc<Path>

Creates a path that selects the given field of the struct at the given path.

source

pub fn new_union_field(base: Rc<Path>, field_index: usize) -> Rc<Path>

Creates a path that selects the given union field of the union at the given path.

source

pub fn new_downcast(base: Rc<Path>, downcast_variant: usize) -> Rc<Path>

Creates a path that selects the given downcast of the enum at the given path.

source

pub fn new_function(func_id: FuncId) -> Rc<Path>

Creates a path referring to function item.

source

pub fn new_type(index: usize) -> Rc<Path>

Creates a path referring to a type item.

source

pub fn new_deref(address_path: Rc<Path>) -> Rc<Path>

Creates a path to the target memory of a reference value.

source

pub fn dyn_ptr_metadata(dyn_ptr_path: &Rc<Path>) -> Rc<Path>

Creates a path representing the metadata of a dynamic pointer.

source

pub fn append_projection_elem( path: &Rc<Path>, projection_elem: PathSelector ) -> Rc<Path>

Creates a path by appending the projection elem.

source

pub fn append_projection( path: &Rc<Path>, projection_elems: &ProjectionElems ) -> Rc<Path>

Creates a path by appending the projection elems.

source

pub fn add_offset(path: &Rc<Path>, offset: usize) -> Rc<Path>

source

pub fn truncate_projection_elems(path: &Rc<Path>, len: usize) -> Rc<Path>

Creates a path by truncating the projection elems.

source

pub fn remove_cast(path: &Rc<Path>) -> Rc<Path>

Returns the original path by removing the cast.

source

pub fn is_constant(&self) -> bool