Trait rupta::mir::path::PathSupport

source ·
pub trait PathSupport {
    // Required methods
    fn is_field_of(&self, path: &Rc<Path>) -> bool;
    fn is_deref_path(&self) -> bool;
}

Required Methods

source

fn is_field_of(&self, path: &Rc<Path>) -> bool

source

fn is_deref_path(&self) -> bool

Implementations on Foreign Types

source

impl PathSupport for Rc<Path>

source

fn is_field_of(&self, path: &Rc<Path>) -> bool

Returns true if this path is the field of the given path. e.g. _1.0.1 and _1.0

source

fn is_deref_path(&self) -> bool

Returns true if this path represents a dereferenced value or a field of a dereferenced value.

Implementors