Struct rupta::pts_set::points_to::HybridPointsToSet
source · pub struct HybridPointsToSet<T> { /* private fields */ }Expand description
Hybrid implementation of points to set, which uses an explicit array for small sets, and a bit vector for large sets.