Struct rupta::util::bit_vec::BitVec

source ·
pub struct BitVec<T> { /* private fields */ }
A growable bit-vector type with a dense representation.

T is an index type, typically a newtyped usize wrapper, but it can also just be usize.

Implementations

source

impl<T: Idx> BitVec<T>

source

pub fn new_empty() -> BitVec<T>

Creates a new, empty bitvec with 0 elements.

source

pub fn with_capacity(capacity: usize) -> BitVec<T>

Creates a new, empty bitvec with a given capacity.

source

pub fn from_vec(from: &Vec<T>) -> BitVec<T>

Creates a new bit vec from a give vec.

source

pub fn ensure(&mut self, capacity: usize)

Ensure that the set can hold at least capacity elements.

source

pub fn clear(&mut self)

Clear all elements.

source

pub fn count(&self) -> usize

Count the number of set bits in the set.

source

pub fn contains(&self, elem: T) -> bool

Returns true if self contains elem.

source

pub fn superset(&self, other: &BitVec<T>) -> bool

Is self is a (non-strict) superset of other?

source

pub fn is_empty(&self) -> bool

Is the set empty?

source

pub fn insert(&mut self, elem: T) -> bool

Insert elem. Returns whether the set has changed.

source

pub fn insert_all(&mut self)

Sets all bits to true.

source

pub fn remove(&mut self, elem: T) -> bool

Returns true if the set has changed.

source

pub fn words(&self) -> &[u64]

Gets a slice of the underlying words.

source

pub fn iter(&self) -> BitIter<'_, T>

Iterates over the indices of set bits in a sorted order.

source

pub fn union(&mut self, other: &BitVec<T>) -> bool

source

pub fn subtract(&mut self, other: &BitVec<T>) -> bool

source

pub fn intersect(&mut self, other: &BitVec<T>) -> bool