Struct rupta::util::chunked_queue::ChunkedQueue
source · pub struct ChunkedQueue<T> { /* private fields */ }Expand description
This queue is implemented as a linked list of chunks, where each chunk is a small buffer
that can hold a handful of elements.
Chunks need to be dynamically allocated as elements get pushed.
This queue is supposed to be faster thanthan LinkedList.
Implementations
sourceimpl<T> ChunkedQueue<T>
impl<T> ChunkedQueue<T>
sourceimpl<T: Copy> ChunkedQueue<T>
impl<T: Copy> ChunkedQueue<T>
sourcepub fn iter_copied(&self) -> IterCopied<T> ⓘ
pub fn iter_copied(&self) -> IterCopied<T> ⓘ
Provides a forward copied iterator.