Function rupta::util::find_sysroot

source ·
pub fn find_sysroot() -> String
Returns the location of the rust system binaries that are associated with this build of rust-pta. The location is obtained by looking at the contents of the environmental variables that were set at the time rust-pta was compiled. If the rust compiler was installed by rustup, the variables RUSTUP_HOME and RUSTUP_TOOLCHAIN are used and these are set by the compiler itself. If the rust compiler was compiled and installed in some other way, for example from a source enlistment, then the RUST_SYSROOT variable must be set in the environment from which rust-pta is compiled.