Enum rupta::util::index_tree::NodeEdge
source · pub enum NodeEdge {
Start(usize),
End(usize),
}Expand description
Indicator if the node is at a start or endpoint of the tree
Variants
Start(usize)
Indicates that start of a node that has children.
Yielded by Traverse::next() before the node’s descendants.
End(usize)
Indicates that end of a node that has children.
Yielded by Traverse::next() after the node’s descendants.