pub struct IndexTree<T> { /* private fields */ }
A tree structure implemented using a single Vec and numerical identifiers (indices in the vector) instead of reference counted pointers like.

Implementations

source

impl<T> IndexTree<T>

source

pub fn new_root(data: T) -> IndexTree<T>

Creates a new empty Tree

source

pub fn count(&self) -> usize

Counts the number of nodes

source

pub fn get(&self, id: usize) -> Option<&Node<T>>

Returns a reference to the node with the given id if in the tree.

source

pub fn get_mut(&mut self, id: usize) -> Option<&mut Node<T>>

Returns a mutable reference to the node with the given id if in the tree.

source

pub fn add_child(&mut self, parent_id: usize, data: T) -> usize

Appends a new child to the node with parent_id, after existing children.

source

pub fn children(&self, id: usize) -> Children<'_, T>

Returns an iterator of IDs of a given node’s children.

source

pub fn find_child<F>(&self, parent_id: usize, f: F) -> Option<usize>
where F: Fn(&T) -> bool,

Finds the child specified by the predicate.

source

pub fn descendants(&self, id: usize) -> Descendants<'_, T>

An iterator of the IDs of a given node and its descendants, as a pre-order depth-first search where children are visited in insertion order.