pub fn equivalent_ptr_types<'tcx>(
    tcx: TyCtxt<'tcx>,
    ty1: Ty<'tcx>,
    ty2: Ty<'tcx>
) -> bool
Returns true if the given two pointer types are equivalent. We suppose that a reference type and a mut/const raw pointer type are equivalent if their dereference types are equivalent.
Pointers of equivalent types can point to the same object.