Function rupta::util::type_util::is_basic_type
source · pub fn is_basic_type(ty: Ty<'_>) -> boolExpand description
Returns whether the type is a primitive type or an array or slice containing basic ty elements e.g. u8, u8, ()