pub struct PathCastCache<'tcx> { /* private fields */ }
Manage the type cast for paths

Implementations

source

impl<'tcx> PathCastCache<'tcx>

source

pub fn new() -> PathCastCache<'tcx>

source

pub fn get_cast_types(&self, path: &Rc<Path>) -> Option<&HashSet<Ty<'tcx>>>

Returns the types that a path may be cast to

source

pub fn cast_to( &mut self, acx: &mut AnalysisContext<'tcx, '_>, path: &Rc<Path>, ty: Ty<'tcx> ) -> Option<Rc<Path>>

Creates a path that casts the given path to a given type

source

pub fn get_type_variant( &mut self, acx: &mut AnalysisContext<'tcx, '_>, path: &Rc<Path>, ty: Ty<'tcx> ) -> Option<Rc<Path>>

source

pub fn get_regularized_path( acx: &mut AnalysisContext<'tcx, '_>, path: Rc<Path> ) -> Rc<Path>

Different paths may refer to the same memory location, we can regularize these path to a base path e.g. a.0.0, a.0, a.cast#T’ and a are all represented by one path