Struct rupta::util::type_util::PointerProjectionsCache
source · pub struct PointerProjectionsCache<'tcx> { /* private fields */ }Expand description
Provides a way to effectively get the pointer type fields of a given type.
Implementations
sourceimpl<'tcx> PointerProjectionsCache<'tcx>
impl<'tcx> PointerProjectionsCache<'tcx>
pub fn new() -> PointerProjectionsCache<'tcx>
sourcepub fn get_pointer_projections(
&mut self,
tcx: TyCtxt<'tcx>,
base_ty: Ty<'tcx>
) -> &Vec<(ProjectionElems, Ty<'tcx>)>
pub fn get_pointer_projections( &mut self, tcx: TyCtxt<'tcx>, base_ty: Ty<'tcx> ) -> &Vec<(ProjectionElems, Ty<'tcx>)>
Get or fetch the pointer type fields of the given base ty.