Struct rupta::util::type_util::TypeCache

source ·
pub struct TypeCache<'tcx> { /* private fields */ }
Provides a way to refer to a rustc_middle::ty::Ty via a handle that does not have a life time specifier.

Implementations

source

impl<'tcx> TypeCache<'tcx>

source

pub fn new() -> TypeCache<'tcx>

source

pub fn get_index(&mut self, ty: &Ty<'tcx>) -> usize

Returns a non zero index that can be used to retrieve ty via get_type.

source

pub fn get_type(&self, index: usize) -> Option<Ty<'tcx>>

Returns the type that was stored at this index, or None if index is zero or greater than the length of the type list.

source

pub fn type_list(&self) -> &Vec<Ty<'tcx>>