Function rupta::builder::call_graph_builder::resolve_fn_def
source · pub fn resolve_fn_def<'tcx>(
tcx: TyCtxt<'tcx>,
def_id: DefId,
gen_args: GenericArgsRef<'tcx>
) -> (DefId, GenericArgsRef<'tcx>)Expand description
Try to resolve the function with def_id and gen_args.
If the function is not a trait method, (def_id, gen_args) is returned
directly. Otherwise, the function is devirtualized to a specific implementation.