Type Alias rupta::graph::call_graph::CSCallGraph
source · pub type CSCallGraph = CallGraph<CSFuncId, CSBaseCallSite>;Aliased Type
struct CSCallGraph {
pub graph: Graph<CallGraphNode<CSFuncId>, CallGraphEdge<BaseCallSiteS<CSFuncId>>>,
pub func_nodes: HashMap<CSFuncId, NodeIndex>,
pub callsite_to_edges: HashMap<BaseCallSiteS<CSFuncId>, HashSet<EdgeIndex>>,
/* private fields */
}Fields
graph: Graph<CallGraphNode<CSFuncId>, CallGraphEdge<BaseCallSiteS<CSFuncId>>>The graph structure capturing call relationships.
func_nodes: HashMap<CSFuncId, NodeIndex>A map from functions to their corresponding call graph nodes.
callsite_to_edges: HashMap<BaseCallSiteS<CSFuncId>, HashSet<EdgeIndex>>A map from call sites to call graph edges.