pub struct Context<E: ContextElement> { /* private fields */ }Expand description
A context is composed of a list of context elements, e.g. callsites.
Implementations
sourceimpl<E: ContextElement> Context<E>
impl<E: ContextElement> Context<E>
pub fn new_empty() -> Rc<Self>
pub fn new(context_elems: Vec<E>) -> Rc<Self>
pub fn len(&self) -> usize
sourcepub fn new_k_limited_context(
old_ctx: &Rc<Context<E>>,
elem: E,
k: usize
) -> Rc<Self>
pub fn new_k_limited_context( old_ctx: &Rc<Context<E>>, elem: E, k: usize ) -> Rc<Self>
Composes a new context from a given context and a new context element. Discard the last old context element if the length of context exceeds the depth limit.
pub fn k_limited_context(ctx: &Rc<Context<E>>, k: usize) -> Rc<Self>
pub fn first_context_element(&self) -> Option<&E>
pub fn last_context_element(&self) -> Option<&E>