pub struct BitVec<T> { /* private fields */ }Expand description
A growable bit-vector type with a dense representation.
T is an index type, typically a newtyped usize wrapper, but it can also
just be usize.
Implementations
sourceimpl<T: Idx> BitVec<T>
impl<T: Idx> BitVec<T>
sourcepub fn with_capacity(capacity: usize) -> BitVec<T>
pub fn with_capacity(capacity: usize) -> BitVec<T>
Creates a new, empty bitvec with a given capacity.
sourcepub fn ensure(&mut self, capacity: usize)
pub fn ensure(&mut self, capacity: usize)
Ensure that the set can hold at least capacity elements.
sourcepub fn insert_all(&mut self)
pub fn insert_all(&mut self)
Sets all bits to true.
sourcepub fn iter(&self) -> BitIter<'_, T> ⓘ
pub fn iter(&self) -> BitIter<'_, T> ⓘ
Iterates over the indices of set bits in a sorted order.
pub fn union(&mut self, other: &BitVec<T>) -> bool
pub fn subtract(&mut self, other: &BitVec<T>) -> bool
pub fn intersect(&mut self, other: &BitVec<T>) -> bool