Function rupta::util::type_util::equivalent_ptr_types
source · pub fn equivalent_ptr_types<'tcx>(
tcx: TyCtxt<'tcx>,
ty1: Ty<'tcx>,
ty2: Ty<'tcx>
) -> boolExpand description
Returns true if the given two pointer types are equivalent.
We suppose that a reference type and a mut/const raw pointer type are equivalent if
their dereference types are equivalent.
Pointers of equivalent types can point to the same object.