Function rupta::util::type_util::flatten_fields
source · pub fn flatten_fields<'tcx>(
tcx: TyCtxt<'tcx>,
param_env: ParamEnv<'tcx>,
path: Rc<Path>,
path_ty: Ty<'tcx>
) -> Vec<(usize, Rc<Path>, Ty<'tcx>)>Expand description
Given an object that may contain nested objects, flatten it by extracting all the bottom-level subobjects. This function returns a vector of tuples, each including a subobject’s memory offset from the base object, its path representation and its type.