Function rupta::util::type_util::is_slice_pointer
source · pub fn is_slice_pointer<'tcx>(ty: Ty<'tcx>) -> boolExpand description
Returns true if the given type is a reference (or raw pointer) to a collection type, in which case the reference/pointer independently tracks the length of the collection, thus effectively tracking a slice of the underlying collection.