pub struct TypeCache<'tcx> { /* private fields */ }Expand description
Provides a way to refer to a rustc_middle::ty::Ty via a handle that does not have a life time specifier.
Implementations
sourceimpl<'tcx> TypeCache<'tcx>
impl<'tcx> TypeCache<'tcx>
pub fn new() -> TypeCache<'tcx>
sourcepub fn get_index(&mut self, ty: &Ty<'tcx>) -> usize
pub fn get_index(&mut self, ty: &Ty<'tcx>) -> usize
Returns a non zero index that can be used to retrieve ty via get_type.
sourcepub fn get_type(&self, index: usize) -> Option<Ty<'tcx>>
pub fn get_type(&self, index: usize) -> Option<Ty<'tcx>>
Returns the type that was stored at this index, or None if index is zero or greater than the length of the type list.
pub fn type_list(&self) -> &Vec<Ty<'tcx>>